import matplotlib.pyplot as plt
import numpy as np
from thermo import *
from fluids.numerics import logspace
from math import log10

thing = PR(P=1e5, T=460, Tc=658.0, Pc=1820000.0, omega=0.9)

Ts = logspace(log10(1000), log10(2000000), 100)
Ps = []
for T in Ts:
    try:
        Ps.append(thing.to(T=T, V=thing.V_l).P)
    except ValueError:
        Ps.append(1e5)

plt.loglog(Ts, Ps)
plt.xlabel('Temperature [K]')
plt.ylabel('Pressure [Pa]')
plt.title("Constant-volume calculated pressure at V=%.8f m^3/mol" %(thing.V_l))
#plt.show()



import matplotlib.pyplot as plt
import numpy as np
from thermo import *
from fluids.numerics import logspace
from math import log10

obj = PRTranslatedConsistent(Tc=190.564, Pc=4599000.0, omega=0.008, T=300., P=1e5)
fig = obj.PT_surface_special(show=False, pts=50)
plt.show()



import matplotlib.pyplot as plt
import numpy as np
from thermo import *
from fluids.numerics import logspace

ethanol_psat = VaporPressure(Tb=351.39, Tc=514.0, Pc=6137000.0, omega=0.635, CASRN='64-17-5')
ethanol_psat.plot_T_dependent_property(Tmin=400, Tmax=500, methods=['BOILING_CRITICAL', 'SANJARI', 'LEE_KESLER_PSAT', 'VDI_TABULAR', 'DIPPR_PERRY_8E'], pts=50, order=1)



import matplotlib.pyplot as plt
import numpy as np
from thermo import *
from fluids.numerics import logspace

water_psat = VaporPressure(Tb=373.124, Tc=647.14, Pc=22048320.0, omega=0.344, CASRN='7732-18-5')

water_mu = ViscosityLiquid(CASRN="7732-18-5", MW=18.01528, Tm=273.15, Tc=647.14, Pc=22048320.0, 
                      Vc=5.6e-05, omega=0.344,method="DIPPR_PERRY_8E", Psat=water_psat,
                      method_P="LUCAS")
methods = ['COOLPROP','LUCAS'] if coolprop.has_CoolProp() else ['LUCAS']
try:
    water_mu.plot_TP_dependent_property(Tmin=400, Pmin=1e5, Pmax=1e8, methods_P=methods, pts=15, only_valid=False)
except:
    pass



import matplotlib.pyplot as plt
import numpy as np
from thermo import *
from fluids.numerics import logspace

ethanol_psat = VaporPressure(Tb=351.39, Tc=514.0, Pc=6137000.0, omega=0.635, CASRN='64-17-5')
methods = ['WAGNER_MCGARRY', 'DIPPR_PERRY_8E', 'COOLPROP'] if coolprop.has_CoolProp() else ['WAGNER_MCGARRY', 'DIPPR_PERRY_8E']

ethanol_psat.plot_T_dependent_property(Tmin=400, Tmax=500, methods=methods, pts=30)



import matplotlib.pyplot as plt
import numpy as np
from thermo import *
from fluids.numerics import logspace
from math import log10

eos = SRK(Tc=507.6, Pc=3025000, omega=0.2975, T=400., P=1E6)
eos.Psat_errors(plot=True, show=True)



import matplotlib.pyplot as plt
import numpy as np
from thermo import *
from fluids.numerics import logspace

ethanol_psat = VaporPressure(Tb=351.39, Tc=514.0, Pc=6137000.0, omega=0.635, CASRN='64-17-5')

methods = ['VDI_TABULAR', 'DIPPR_PERRY_8E', 'COOLPROP'] if coolprop.has_CoolProp() else ['VDI_TABULAR', 'DIPPR_PERRY_8E']
ethanol_psat.plot_T_dependent_property(Tmin=1, Tmax=300, methods=methods, pts=50, only_valid=False)
